/*
 * Copyright (c) 2023 - 2024. KeyWare.Co.Ltd All rights reserved.
 * 项目名称：Java 信息安全性设计准则
 * 项目描述：用于检查Java源代码的安全性设计准则的Sonarqube插件
 * 版权说明：本软件属北京关键科技股份有限公司所有，在未获得北京关键科技股份有限公司正式授权情况下，任何企业和个人，不能获取、阅读、安装、传播本软件涉及的任何受知识产权保护的内容。
 */
package com.keyware.sonar.java;

import com.keyware.sonar.java.rules.JavaSecurityDesignRulesRepository;
import org.sonar.api.server.profile.BuiltInQualityProfilesDefinition;
import org.sonarsource.api.sonarlint.SonarLintSide;

/**
 * 定义一个内置的Java安全设计规则集质量配置
 *
 * @author GuoXin
 * @date 2024/1/11
 */
@SonarLintSide
public class JavaSecurityDesignWayProfile implements BuiltInQualityProfilesDefinition {

    @Override
    public void define(Context context) {
        var way = context.createBuiltInQualityProfile("Java信息安全性设计准则", "java");
        way.activateRule(JavaSecurityDesignRulesRepository.REPOSITORY_KEY, "ABCVarNameChecker");
        way.activateRule(JavaSecurityDesignRulesRepository.REPOSITORY_KEY, "AbsolutePathDetectorChecker");
        way.activateRule(JavaSecurityDesignRulesRepository.REPOSITORY_KEY, "DynamicCodeChecker");
        way.activateRule(JavaSecurityDesignRulesRepository.REPOSITORY_KEY, "DynamicLibraryLoadChecker");
        way.done();
    }
}
